@@ -26,6 +26,7 @@ run_dsa <- function(model, dsa) {
   list_res <- list()
   e_newdata <- list()
   for (n in strategy_names) {
+    if (!identical(Sys.getenv("TESTTHAT"), "true")) 
     message(sprintf(
       "Running DSA on strategy '%s'...", n
     ))
@@ -83,7 +84,7 @@ run_dsa <- function(model, dsa) {
     dplyr::mutate(
       .par_value_eval = unlist(e_newdata)) %>% 
     dplyr::mutate(
-      !!! compat_lazy_dots(get_ce(model)))
+      !!! get_ce(model))
   
   
   structure(
